# libgetar

[![PyPI](https://img.shields.io/pypi/v/gtar.svg?style=flat)](https://pypi.org/project/gtar/)
[![ReadTheDocs](https://img.shields.io/readthedocs/libgetar.svg?style=flat)](https://libgetar.readthedocs.io/en/latest/)

Libgetar is a library to read and write GEneric Trajectory ARchives, a binary data format designed for efficient, extensible storage of trajectory data.

Information on installation and common issues can be found in the manual, located at https://libgetar.readthedocs.io/en/latest/ or in the doc subdirectory.

## Credits

libgetar uses portions of the lz4 project, located at http://www.lz4.org/.
Its code and license are located in the lz4 subdirectory.

libgetar uses portions of the miniz project, located at https://github.com/richgel999/miniz.
Its code and license are located in the miniz subdirectory.

libgetar uses portions of the SQLite project, located at https://www.sqlite.org/.
Its code and license are located in the sqlite3 subdirectory.

libgetar uses portions of Dirent, located at https://github.com/tronkko/dirent.
Its code and license are located in the dirent subdirectory.
